summaryrefslogtreecommitdiffstats
path: root/src/cpu/amd
diff options
context:
space:
mode:
authorRonald G. Minnich <rminnich@gmail.com>2006-05-18 03:07:16 +0000
committerRonald G. Minnich <rminnich@gmail.com>2006-05-18 03:07:16 +0000
commitbad9d105cf908bbb032768a1605265654b38ca3a (patch)
tree264093bd7636f621345cc232d0dbbf2a003f9c56 /src/cpu/amd
parent5d573c28e7520085ff7b687c05834292d615860a (diff)
downloadcoreboot-staging-bad9d105cf908bbb032768a1605265654b38ca3a.zip
coreboot-staging-bad9d105cf908bbb032768a1605265654b38ca3a.tar.gz
cleanup some of the compressed rom stream ugliness -- more to do!
olpc and rumba can now boot linux out of flash. vsa was resized to 64K. olpc and rumba now used compressed payload -- thanks stefan! git-svn-id: svn://svn.coreboot.org/coreboot/trunk@2307 2b7e53f0-3cfb-0310-b3e9-8179ed1497e1
Diffstat (limited to 'src/cpu/amd')
-rw-r--r--src/cpu/amd/model_gx2/vsmsetup.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cpu/amd/model_gx2/vsmsetup.c b/src/cpu/amd/model_gx2/vsmsetup.c
index dacaef8..62e1789 100644
--- a/src/cpu/amd/model_gx2/vsmsetup.c
+++ b/src/cpu/amd/model_gx2/vsmsetup.c
@@ -261,8 +261,8 @@ void do_vsmbios(void)
*/
//rom = 0xfff80000;
//rom = 0xfffc0000;
- /* the VSA starts at the base of rom - 128k */
- rom = ((unsigned long) 0) - (ROM_SIZE + 128*1024);
+ /* the VSA starts at the base of rom - 64 */
+ rom = ((unsigned long) 0) - (ROM_SIZE + 64*1024);
buf = (unsigned char *) rom;
printk_debug("buf %p *buf %d buf[256k] %d\n",
OpenPOWER on IntegriCloud